@@ -14,6 +14,8 @@ module ActsAsTaggableOn
     scope :by_contexts, ->(contexts) { where(context: (contexts || DEFAULT_CONTEXT)) }
     scope :by_context, ->(context = DEFAULT_CONTEXT) { by_contexts(context.to_s) }
 
+    scope :by_tenant, ->(tenant) { where(tenant: tenant) }
+
     validates_presence_of :context
     validates_presence_of :tag_id
 
@@ -28,7 +30,7 @@ module ActsAsTaggableOn
         if ActsAsTaggableOn.tags_counter
           tag.destroy if tag.reload.taggings_count.zero?
         else
-          tag.destroy if tag.reload.taggings.count.zero?
+          tag.destroy if tag.reload.taggings.none?
         end
       end
     end
