@@ -49,6 +49,22 @@ describe ActsAsTaggableOn::Tagging do
     ActsAsTaggableOn.remove_unused_tags = previous_setting
   end
 
+  it 'should destroy unused tags after tagging destroyed when not using tags_counter' do
+    remove_unused_tags_previous_setting = ActsAsTaggableOn.remove_unused_tags
+    tags_counter_previous_setting = ActsAsTaggableOn.tags_counter
+    ActsAsTaggableOn.remove_unused_tags = true
+    ActsAsTaggableOn.tags_counter = false
+
+    ActsAsTaggableOn::Tag.destroy_all
+    @taggable = TaggableModel.create(name: 'Bob Jones')
+    @taggable.update_attribute :tag_list, 'aaa,bbb,ccc'
+    @taggable.update_attribute :tag_list, ''
+    expect(ActsAsTaggableOn::Tag.count).to eql(0)
+
+    ActsAsTaggableOn.remove_unused_tags = remove_unused_tags_previous_setting
+    ActsAsTaggableOn.tags_counter = tags_counter_previous_setting
+  end
+
   describe 'context scopes' do
     before do
       @tagging_2 = ActsAsTaggableOn::Tagging.new
@@ -61,12 +77,14 @@ describe ActsAsTaggableOn::Tagging do
       @tagging.tag = ActsAsTaggableOn::Tag.create(name: "Physics")
       @tagging.tagger = @tagger
       @tagging.context = 'Science'
+      @tagging.tenant = 'account1'
       @tagging.save
 
       @tagging_2.taggable = TaggableModel.create(name: "Satellites")
       @tagging_2.tag = ActsAsTaggableOn::Tag.create(name: "Technology")
       @tagging_2.tagger = @tagger_2
       @tagging_2.context = 'Science'
+      @tagging_2.tenant = 'account1'
       @tagging_2.save
 
       @tagging_3.taggable = TaggableModel.create(name: "Satellites")
@@ -98,6 +116,14 @@ describe ActsAsTaggableOn::Tagging do
       end
     end
 
+    describe '.by_tenant' do
+      it "should find taggings by tenant" do
+        expect(ActsAsTaggableOn::Tagging.by_tenant('account1').length).to eq(2);
+        expect(ActsAsTaggableOn::Tagging.by_tenant('account1').first).to eq(@tagging);
+        expect(ActsAsTaggableOn::Tagging.by_tenant('account1').second).to eq(@tagging_2);
+      end
+    end
+
     describe '.not_owned' do
       before do
         @tagging_4 = ActsAsTaggableOn::Tagging.new
